@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2016 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2017 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_RUNTIME_TRACE_H
@@ -13,7 +13,7 @@
 
 struct sieve_runtime_trace {
 	struct sieve_trace_config config;
-	struct ostream *stream;
+	struct sieve_trace_log *log;
 	unsigned int indent;
 };
 
